is_system_schema

Function is_system_schema 

pub fn is_system_schema(schema: &str) -> bool
Helper to check if a schema name is a system schema. Used for dependency tracking to avoid tracking dependencies on system objects.