Module schema_ops

Module schema_ops 

Structs

SchemaOpsConfig

Functions

apply_current_schema_to_shadow
Apply current schema from config to shadow database
apply_roles_file
Apply roles file to a database if it exists
apply_schema_to_shadow_with_roles
Apply schema to shadow database with roles file support and optional file dependency augmentation
load_and_apply_schema
Load and apply schema files to a database